@@ -18,7 +18,7 @@ class server:
         ip = str(data["mailip"])
         port = int(data["mailport"])
         if debug == "on":
-            print("[60%] Server IP "+ip)
+            print("[60%] Server IP "+ip+":"+str(port))
         message = " ".join([str(m) for m in message])
         client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         client.connect((ip, port))
@@ -60,6 +60,21 @@ class server:
         client.shutdown(socket.SHUT_RDWR)
         client.close()
         return free
+    def validate(email:str):
+        url = "https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json"
+        http = urllib3.PoolManager()
+        request = http.request('GET', url)
+        data = json.loads(request.data.decode('utf8'))
+        ip = str(data["mailip"])
+        port = int(data["mailport"])
+        client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        client.connect((ip, port))
+        client.sendall(bytes("free|email|validation|"+email,'UTF-8'))
+        check = client.recv(1024)
+        check = check.decode('utf-8')
+        client.shutdown(socket.SHUT_RDWR)
+        client.close()
+        return check
     def regions():
         return "SMTP regions: tr, ru, ua, us, uk, de, fr, it"
     def debug(type:str):
@@ -68,3 +83,4 @@ class server:
             debug = "on"
         else:
             debug = "off"
+
